@@ -1,6 +1,6 @@
 from datetime import datetime
 import aiohttp
-from .statistics import GlobalStatistics, CountryStatistics, StateStatistics, CountryHistory
+from .statistics import GlobalStatistics, CountryStatistics, StateStatistics, CountryHistory, HistoryEntry
 
 class APIerror(Exception):
     pass
@@ -17,7 +17,7 @@ class Client:
         self.all_countries = 'https://corona.lmao.ninja/countries'
         self.country_data = 'https://corona.lmao.ninja/countries/{}'
         self.states = 'https://corona.lmao.ninja/states'
-        self.historical = 'https://corona.lmao.ninja/historical/{}'
+        self.historical = 'https://corona.lmao.ninja/v2/historical/{}'
 
 
     async def all(self):
@@ -80,6 +80,7 @@ class Client:
         today_deaths = country_stats.get("todayDeaths", 0)
         total_critical = country_stats.get("critical", 0)
         cases_per_million = country_stats.get("casesPerOneMillion", 0)
+        flag = country_stats["countryInfo"].get("flag", None)
         
         return CountryStatistics(
             country_name,
@@ -89,7 +90,8 @@ class Client:
             today_cases,
             today_deaths,
             total_critical,
-            cases_per_million
+            cases_per_million,
+            flag
             )
         
     
@@ -130,36 +132,62 @@ class Client:
         """
         Get historical data for a specific country.
         """
-        if country.lower() == 'usa' or country.lower() == 'united states':
-            country = 'us'
-        elif country.lower() == 'uk':
-            country = 'united kingdom'
-        elif 'korea' in country.lower():
-            country = 'korea, south' #no stats for north korea
-
         async with self.session.get(self.historical.format(country)) as resp:
             if not resp.status == 200:
                 raise APIerror('Failed to get historical data.')
 
             historical_stats = await resp.json()
 
-        case_history = {}
-        death_history = {}
-        recovery_history = {}
+        case_history = []
+        death_history = []
+        #recovery_history = []
                 
-        name = historical_stats["country"].title()
+        name = historical_stats["standardizedCountryName"]
 
         if not historical_stats["timeline"]["cases"]:
             raise APIerror('Couldn\'t get stats for given country')
 
         for date in list(historical_stats["timeline"]["cases"].keys()): #pass on all historical data. let the client decide how much of it they want
-            case_history[date] = historical_stats["timeline"]["cases"][date]
-            death_history[date] = historical_stats["timeline"]["deaths"][date]
-            recovery_history[date] = historical_stats["timeline"]["recovered"][date]
+            case_history.append(HistoryEntry(date, historical_stats["timeline"]["cases"][date]))
+            death_history.append(HistoryEntry(date, historical_stats["timeline"]["deaths"][date]))
+            #recovery_history.append(HistoryEntry(date, historical_stats["timeline"]["recovered"][date])) #history v2 no longer includes recovery data
 
-        compiled_data = []
-        compiled_data.append(case_history)
-        compiled_data.append(death_history)
-        compiled_data.append(recovery_history)
+        return CountryHistory(name, case_history, death_history) #, recovery_history)
 
-        return CountryHistory(name, compiled_data)
+
+    async def get_sorted_data(self, sort):
+        """
+        Get the data for all countries sorted by the parameter given.
+        When sorted alphabetically, data is returned Z-A rather than A-Z.
+        If the user wishes to reverse it, they are able to use list.reverse()
+        """
+        if sort != "cases" and sort != "deaths" and sort != "recovered" and sort != "alphabetical" and sort != "country"\
+        and sort != "todayCases" and sort != "todayDeaths" and sort != "casesPerOneMillion":
+            raise APIerror('Invalid sort parameter')
+        
+        if sort == "alphabetical":
+            sort = "country"
+
+        async with self.session.get('{}?sort={}'.format(self.all_countries, sort)) as resp:
+            if not resp.status == 200:
+                raise APIerror('Unexpected error, code {}'.format(resp.status))
+
+            data = await resp.json()
+
+        sorted_data = []
+
+        for country in data:
+            c = CountryStatistics(
+                country["country"],
+                country["cases"],
+                country["deaths"],
+                country["recovered"],
+                country["todayCases"],
+                country["todayDeaths"],
+                country["critical"],
+                country["casesPerOneMillion"],
+                country["countryInfo"]["flag"]
+            )
+            sorted_data.append(c)
+        
+        return sorted_data
