@@ -10,7 +10,7 @@ class GlobalStatistics:
 
 
 class CountryStatistics:
-    def __init__(self, name, cases, deaths, recoveries, today_cases, today_deaths, critical, cases_per_million):
+    def __init__(self, name, cases, deaths, recoveries, today_cases, today_deaths, critical, cases_per_million, flag):
         self.name = name
         self.cases = cases
         self.deaths = deaths
@@ -19,6 +19,7 @@ class CountryStatistics:
         self.today_deaths = today_deaths
         self.critical = critical
         self.cases_per_million = cases_per_million
+        self.flag = flag
 
 
 class StateStatistics:
@@ -32,9 +33,15 @@ class StateStatistics:
         self.active = active
 
 
+class HistoryEntry:
+    def __init__(self, date, value):
+        self.date = date
+        self.value = value
+
+
 class CountryHistory:
-    def __init__(self, name, dicts):
+    def __init__(self, name, case_history, death_history): # , recovery_history):
         self.name = name
-        self.case_history = dicts[0]
-        self.death_history = dicts[1]
-        self.recovery_history = dicts[2]
\ No newline at end of file
+        self.case_history = case_history
+        self.death_history = death_history
+        #self.recovery_history = recovery_history
\ No newline at end of file
